# Design

`python-code-data` is designd around a couple of patterns, to keep it consistant.

1. Remove all extra information which is semantically redundant.
2. Only use builtin immutable Python data structures, which are hashable.
